library soliq_id;

import 'package:camera/camera.dart';
import 'package:dio/dio.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:soliq_id/src/data/api/soliq_id_api.dart';
import 'package:soliq_id/src/data/bloc/soliq_id_bloc.dart';
import 'package:soliq_id/src/data/dio/dio_module.dart';
import 'package:soliq_id/src/data/repository_impl/soliq_id_repository_impl.dart';
import 'package:soliq_id/src/data/storages/preference.dart';

import 'localizations_util.dart';
import 'src/screens/face_id_signin.dart';

List<CameraDescription> cameras = [];
Preference? pref;
Dio? dio;
SoliqIdApi? apiClient;

class SoliqId extends StatefulWidget {
  const SoliqId({
    Key? key,
    required this.pinfl,
    required this.localizationType,
    required this.guid,
  }) : super(key: key);
  final pinfl;
  final LocalizationType localizationType;
  final String guid;

  @override
  State<SoliqId> createState() => _SoliqIdState();
}

class _SoliqIdState extends State<SoliqId> {
  Preference preference = Preference();

  // late final Future getGuidFuture;

  Future<void> _initDio() async {
    final dioModule = DioModule();
    dio = await dioModule.getAuthorizedDioClient();
    if (dio != null) {
      apiClient = SoliqIdApi(dio!);
    }
  }

  @override
  void initState() {
    super.initState();
    getGuid();
  }

  @override
  Widget build(BuildContext context) {
    return FutureBuilder<void>(
      future: _initDio(),
      builder: (context, snapshot) {
        if (snapshot.connectionState == ConnectionState.done) {
          return BlocProvider(
            create: (_) => SoliqIdBloc(
              SoliqIdRepositoryImpl(apiClient!),
            ),
            child: FaceIdSignIn(
              pinfl: widget.pinfl,
              localizationType: widget.localizationType,
              guid: widget.guid,
            ),
          );
        } else {
          return const CircularProgressIndicator();
        }
      },
    );
  }

  Future<void> getGuid() async {
    final locale = getLocalizationType(
      widget.localizationType,
    );
    final preference = Preference();
    await preference.setLang(locale);
    await preference.setGUID(widget.guid);
    cameras = await availableCameras();

    pref = await preference.init();
    await Future.delayed(const Duration(seconds: 2));
  }

  @override
  void dispose() async {
    await preference.removeGUID();
    super.dispose();
  }
}
