import 'dart:async';
import 'dart:developer';

import 'package:equatable/equatable.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import '../model/response/account_info_response.dart';
import '../model/response/create_session_response.dart';
import '../model/response/process_response.dart';
import '../repository/soliq_id_repository.dart';

part 'soliq_id_event.dart';
part 'soliq_id_state.dart';

class SoliqIdBloc extends Bloc<SoliqIdEvent, SoliqIdState> {
  SoliqIdRepository repository;

  SoliqIdBloc(this.repository) : super(SoliqIdInitial()) {
    on<SoliqIdAccountInfoEvent>(_onAccountInfo);
    on<SoliqIdCreateSessionEvent>(_onCreateSession);
    on<SoliqIdProcessEvent>(_onSetProcess);
    on<SoliqIdCompareFaceEvent>(_onSetCompareFace);
  }

  FutureOr<void> _onAccountInfo(
      SoliqIdAccountInfoEvent event, Emitter<SoliqIdState> emit) async {
    try {
      final response = await repository.setAccountInfo(
        pinfl: event.pinfl,
        lang: event.lang,
      );
      // print(Utils.getDeviceDetails().toString());
      emit(SoliqIdAccountInfoSuccessState(
        response: response,
      ));
    } on Object catch (e) {
      log(e.toString());
    }
  }

  FutureOr<void> _onCreateSession(
      SoliqIdCreateSessionEvent event, Emitter<SoliqIdState> emit) async {
    try {
      final response = await repository.createSession(
        pinfl: event.pinfl,
        lang: event.lang,
        fio: event.fio,
      );
      emit(SoliqIdCreateSessionSuccessState(
        response: response,
      ));
    } on Object catch (e) {
      log(e.toString());
    }
  }

  FutureOr<void> _onSetProcess(
      SoliqIdProcessEvent event, Emitter<SoliqIdState> emit) async {
    try {
      final response = await repository.setProcess(
        id: event.id,
        asked: event.asked,
        processId: event.processId,
        date: '',
      );
      emit(SoliqIdProcessSuccessState(
        response: response,
      ));
    } on Object catch (e) {
      log(e.toString());
    }
  }

  FutureOr<void> _onSetCompareFace(
      SoliqIdCompareFaceEvent event, Emitter<SoliqIdState> emit) async {
    try {
      final response = await repository.compareFace(
        id: event.id,
        asked: event.asked,
        processId: event.processId,
        image: event.date,
      );
      emit(SoliqIdCompareFaceSuccessState(
        response: response,
      ));
    } on Object catch (e) {
      log(e.toString());
    }
  }
}
