import 'package:soliq_id/src/utils/utils.dart';

import '../api/soliq_id_api.dart';
import '../model/request/account_info_request.dart';
import '../model/request/compare_face_request.dart';
import '../model/request/create_session_request.dart';
import '../model/request/process_request.dart';
import '../model/response/account_info_response.dart';
import '../model/response/create_session_response.dart';
import '../model/response/process_response.dart';
import '../repository/soliq_id_repository.dart';

class SoliqIdRepositoryImpl implements SoliqIdRepository {
  final SoliqIdApi _soliqIdApi;

  SoliqIdRepositoryImpl(this._soliqIdApi);

  @override
  Future<AccountInfoResponse> setAccountInfo({
    required int pinfl,
    required String lang,
  }) async {
    final deviceInfo = await Utils.getDeviceDetails();
    return await _soliqIdApi.getAccountInfo(AccountInfoRequest(
      device: deviceInfo,
      pinfl: pinfl,
    ));
  }

  @override
  Future<ProcessResponse> compareFace({
    required int id,
    required int asked,
    required String processId,
    required String image,
  }) async {
    final deviceId = await Utils.getDeviceId();
    return await _soliqIdApi.faceCompare(
      CompareFaceRequest(
        deviceId: deviceId,
        processId: processId,
        id: id,
        asked: asked,
        image: image,
      ),
    );
  }

  @override
  Future<CreateSessionResponse> createSession({
    required String lang,
    required int pinfl,
    required String fio,
  }) async {
    final device = await Utils.getDeviceDetails();
    return await _soliqIdApi.session(
      CreateSessionRequest(
        pinfl: pinfl,
        fio: fio,
        device: device,
      ),
    );
  }

  @override
  Future<ProcessResponse> setProcess({
    required int id,
    required int asked,
    required String processId,
    required String date,
  }) async {
    final deviceId = await Utils.getDeviceId();
    return await _soliqIdApi.logsApi(ProcesseRequest(
      deviceId: deviceId,
      processId: processId,
      id: id,
      asked: asked,
      date: date,
    ));
  }
}
